@@ -1,4 +1,8 @@
 package Perlanet::Trait::Scrubber;
+
+use strict;
+use warnings;
+
 use Moose::Role;
 use namespace::autoclean;
 
@@ -32,10 +36,12 @@ sub _build_scrubber {
 
   my %scrub_rules = (
     img => {
-      src   => qr{^http://},    # only URL with http://
+      src   => qr{^https?://},  # only URL with http://
       alt   => 1,               # alt attributes allowed
       align => 1,               # allow align on images
       style => 1,
+      width => 1,
+      height => 1,
       '*'   => 0,               # deny all others
     },
     style => 0,
@@ -82,6 +88,8 @@ sub _build_scrubber {
     'style'       => 1,
     'class'       => 0,
     'id'          => 0,
+    'frameborder' => 0,
+    'border'      => 0,
   );
 
   my $scrub = HTML::Scrubber->new;
@@ -92,11 +100,11 @@ sub _build_scrubber {
 }
 
 around 'clean_html' => sub {
-    my $orig = shift;
-    my ($self, $html) = @_;
-    $html = $self->$orig($html);
-    my $scrubbed = $self->scrubber->scrub($html);
-    return $html;
+  my $orig = shift;
+  my ($self, $html) = @_;
+  $html = $self->$orig($html);
+  my $scrubbed = $self->scrubber->scrub($html);
+  return $scrubbed;
 };
 
 =head1 AUTHOR
@@ -105,7 +113,7 @@ Dave Cross, <dave@mag-sol.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008 by Magnum Solutions Ltd.
+Copyright (c) 2010 by Magnum Solutions Ltd.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
